@@ -75,11 +75,14 @@ from picard.util import (
     emptydir,
     find_best_match,
     format_time,
-    pathcmp,
+    samefile,
     thread,
     tracknum_from_filename,
 )
-from picard.util.filenaming import make_short_filename
+from picard.util.filenaming import (
+    make_short_filename,
+    move_ensure_casing,
+)
 from picard.util.preservedtags import PreservedTags
 from picard.util.scripttofilename import script_to_filename_with_metadata
 from picard.util.tags import PRESERVED_TAGS
@@ -87,6 +90,9 @@ from picard.util.tags import PRESERVED_TAGS
 from picard.ui.item import Item
 
 
+FILE_INFO_TAGS = ('~bitrate', '~sample_rate', '~channels', '~bits_per_sample', '~format')
+
+
 class File(QtCore.QObject, Item):
 
     metadata_images_changed = QtCore.pyqtSignal()
@@ -145,6 +151,7 @@ class File(QtCore.QObject, Item):
 
         self.acoustid_fingerprint = None
         self.acoustid_length = 0
+        self.match_recordingid = None
 
     def __repr__(self):
         return '<%s %r>' % (type(self).__name__, self.base_filename)
@@ -245,6 +252,8 @@ class File(QtCore.QObject, Item):
                 saved_metadata[tag] = values
         deleted_tags = self.metadata.deleted_tags
         self.metadata.copy(metadata)
+        for info in FILE_INFO_TAGS:
+            metadata[info] = self.orig_metadata[info]
         if preserve_deleted:
             for tag in deleted_tags:
                 del self.metadata[tag]
@@ -257,7 +266,7 @@ class File(QtCore.QObject, Item):
 
     def keep_original_images(self):
         self.metadata.images = self.orig_metadata.images.copy()
-        self.update()
+        self.update(signal=False)
         self.metadata_images_changed.emit()
 
     def has_error(self):
@@ -354,8 +363,7 @@ class File(QtCore.QObject, Item):
             self.base_filename = os.path.basename(new_filename)
             length = self.orig_metadata.length
             temp_info = {}
-            for info in ('~bitrate', '~sample_rate', '~channels',
-                         '~bits_per_sample', '~format'):
+            for info in FILE_INFO_TAGS:
                 temp_info[info] = self.orig_metadata[info]
             # Data is copied from New to Original because New may be
             # a subclass to handle id3v23
@@ -457,17 +465,18 @@ class File(QtCore.QObject, Item):
                 new_dirname = os.path.normpath(os.path.join(os.path.dirname(filename), new_dirname))
         else:
             new_dirname = os.path.dirname(filename)
+        try:
+            new_dirname = os.path.realpath(new_dirname)
+        except FileNotFoundError:
+            # os.path.realpath can fail if cwd does not exist and path is relative
+            pass
         new_filename = os.path.basename(filename)
 
         if settings["rename_files"] or settings["move_files"]:
             new_filename = self._format_filename(new_dirname, new_filename, metadata, settings)
 
         new_path = os.path.join(new_dirname, new_filename)
-        try:
-            return os.path.realpath(new_path)
-        except FileNotFoundError:
-            # os.path.realpath can fail if cwd doesn't exist
-            return new_path
+        return new_path
 
     def _rename(self, old_filename, metadata):
         new_filename, ext = os.path.splitext(
@@ -481,13 +490,13 @@ class File(QtCore.QObject, Item):
             os.makedirs(new_dirname)
         tmp_filename = new_filename
         i = 1
-        while (not pathcmp(old_filename, new_filename + ext)
-               and os.path.exists(new_filename + ext)):
+        while (os.path.exists(new_filename + ext)
+               and not samefile(old_filename, new_filename + ext)):
             new_filename = "%s (%d)" % (tmp_filename, i)
             i += 1
         new_filename = new_filename + ext
         log.debug("Moving file %r => %r", old_filename, new_filename)
-        shutil.move(old_filename, new_filename)
+        move_ensure_casing(old_filename, new_filename)
         return new_filename
 
     def _save_images(self, dirname, metadata):
@@ -821,22 +830,6 @@ class File(QtCore.QObject, Item):
     def iterfiles(self, save=False):
         yield self
 
-    @property
-    def tracknumber(self):
-        """The track number as an int."""
-        try:
-            return int(self.metadata["tracknumber"])
-        except BaseException:
-            return 0
-
-    @property
-    def discnumber(self):
-        """The disc number as an int."""
-        try:
-            return int(self.metadata["discnumber"])
-        except BaseException:
-            return 0
-
 
 _file_post_load_processors = PluginFunctions(label='file_post_load_processors')
 _file_post_addition_to_track_processors = PluginFunctions(label='file_post_addition_to_track_processors')
