@@ -6,7 +6,7 @@
 # Copyright (C) 2006-2008, 2011-2012 Lukáš Lalinský
 # Copyright (C) 2013-2014 Sophist-UK
 # Copyright (C) 2013-2014, 2018 Laurent Monin
-# Copyright (C) 2014, 2018-2019 Philipp Wolfer
+# Copyright (C) 2014, 2018-2020 Philipp Wolfer
 # Copyright (C) 2016 Christoph Reiter
 # Copyright (C) 2016 Ville Skyttä
 # Copyright (C) 2017 Sambhav Kothari
@@ -41,33 +41,13 @@ except ImportError:
         pass
 
 
-class TCMP(TextFrame):
-    pass
-
-
-class TSO2(TextFrame):
-    pass
-
-
-class TSOC(TextFrame):
-    pass
-
-
-class XDOR(TextFrame):
-    pass
-
-
 class XSOP(TextFrame):
     pass
 
 
 known_frames = dict(Frames)
 known_frames.update(dict(Frames_2_2))
-known_frames["GRP1"] = GRP1
-known_frames["TCMP"] = TCMP
-known_frames["TSO2"] = TSO2
-known_frames["TSOC"] = TSOC
-known_frames["XDOR"] = XDOR
+known_frames["GRP1"] = GRP1  # Available since mutagen >= 1.38
 known_frames["XSOP"] = XSOP
 
 
@@ -75,7 +55,6 @@ class CompatID3(ID3):
 
     """
     Additional features over mutagen.id3.ID3:
-     * iTunes' TCMP frame
      * Allow some v2.4 frames also in v2.3
     """
 
@@ -87,11 +66,15 @@ class CompatID3(ID3):
         super().__init__(*args, **kwargs)
 
     def update_to_v23(self):
-        # leave TSOP, TSOA and TSOT even though they are officially defined
-        # only in ID3v2.4, because most applications use them also in ID3v2.3
-        frames = []
-        for key in ["TSOP", "TSOA", "TSOT", "TSST"]:
-            frames.extend(self.getall(key))
-        super().update_to_v23()
-        for frame in frames:
-            self.add(frame)
+        update_to_v23(self)
+
+
+def update_to_v23(tags):
+    # leave TSOP, TSOA and TSOT even though they are officially defined
+    # only in ID3v2.4, because most applications use them also in ID3v2.3
+    frames = []
+    for key in ["TSOP", "TSOA", "TSOT", "TSST"]:
+        frames.extend(tags.getall(key))
+    ID3.update_to_v23(tags)
+    for frame in frames:
+        tags.add(frame)
